Uses of Class
io.vertx.reactivex.ext.web.handler.APIKeyHandler
Packages that use APIKeyHandler
-
Uses of APIKeyHandler in io.vertx.reactivex.ext.web.handler
Fields in io.vertx.reactivex.ext.web.handler with type parameters of type APIKeyHandlerMethods in io.vertx.reactivex.ext.web.handler that return APIKeyHandlerModifier and TypeMethodDescriptionSpecify the source for the api key extraction as an HTTP cookie with the given name.static APIKeyHandlerAPIKeyHandler.create(AuthenticationProvider authProvider) Create an API Key authentication handlerSpecify the source for the api key extraction as an HTTP header with the given name.static APIKeyHandlerAPIKeyHandler.newInstance(APIKeyHandler arg) Specify the source for the api key extraction as an HTTP query parameter with the given name.APIKeyHandler.tokenExtractor(io.reactivex.functions.Function<String, io.reactivex.Single<String>> tokenExtractor) Transform from user's token format to the AuthenticationHandler's format.APIKeyHandler.tokenExtractor(Function<String, Future<String>> tokenExtractor) Transform from user's token format to the AuthenticationHandler's format. -
Uses of APIKeyHandler in io.vertx.reactivex.ext.web.openapi.router
Methods in io.vertx.reactivex.ext.web.openapi.router with parameters of type APIKeyHandlerModifier and TypeMethodDescriptionSecurity.apiKeyHandler(APIKeyHandler handler) Configure the to be used when creating the router.