Class ArrayParserFactory

java.lang.Object
io.vertx.reactivex.ext.web.validation.builder.ArrayParserFactory
All Implemented Interfaces:
RxDelegate

public class ArrayParserFactory extends Object implements RxDelegate
This interface is used to create able to parse serialized array structures.
Look at Parsers for all available factories

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.