Package io.vertx.reactivex.sqlclient
Class PreparedQuery<T>
java.lang.Object
io.vertx.reactivex.sqlclient.Query<T>
io.vertx.reactivex.sqlclient.PreparedQuery<T>
- All Implemented Interfaces:
RxDelegate
A query for a prepared statement allowing parameterized execution of the query, this query will use
a prepared statement.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionPreparedQuery(PreparedQuery delegate) PreparedQuery(Object delegate, TypeArg<T> typeArg_0) -
Method Summary
Modifier and TypeMethodDescriptionbooleanexecute()Execute the query.Execute the query.executeBatch(List<Tuple> batch) Execute the query with a batch of tuples.inthashCode()<U> PreparedQuery<RowSet<U>>static <T> PreparedQuery<T>newInstance(PreparedQuery arg) static <T> PreparedQuery<T>newInstance(PreparedQuery arg, TypeArg<T> __typeArg_T) io.reactivex.Single<T>Execute the query.io.reactivex.Single<T>Execute the query.io.reactivex.Single<T>rxExecuteBatch(List<Tuple> batch) Execute the query with a batch of tuples.toString()Methods inherited from class io.vertx.reactivex.sqlclient.Query
newInstance, newInstance
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
PreparedQuery
-
PreparedQuery
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classQuery<T>
-
execute
Execute the query. -
rxExecute
Execute the query. -
execute
Execute the query.- Parameters:
tuple-- Returns:
- a future notified with the result
-
rxExecute
Execute the query.- Parameters:
tuple-- Returns:
- a future notified with the result
-
executeBatch
Execute the query with a batch of tuples.- Parameters:
batch- the batch of tuples- Returns:
- a future notified with the result
-
rxExecuteBatch
Execute the query with a batch of tuples.- Parameters:
batch- the batch of tuples- Returns:
- a future notified with the result
-
mapping
-
newInstance
-
newInstance
-