Package io.vertx.reactivex.sqlclient
Class Row
java.lang.Object
io.vertx.reactivex.sqlclient.Tuple
io.vertx.reactivex.sqlclient.Row
- All Implemented Interfaces:
RxDelegate
A single row of the
execution result rowset.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionboolean<T> TLikeTuple.get(java.lang.Class<T>, int)but specifying thecolumninstead of the position.getArrayOfBigDecimals(String column) Get an array of value for the givencolumn.Boolean[]getArrayOfBooleans(String column) Get an array ofBooleanvalue for the givencolumn.Byte[]getArrayOfBytes(String column) Get an array ofBytevalue for the givencolumn.Double[]getArrayOfDoubles(String column) Get an array ofDoublevalue for the givencolumn.Float[]getArrayOfFloats(String column) Get an array ofFloatvalue for the givencolumn.Integer[]getArrayOfIntegers(String column) Get an array ofIntegervalue for the givencolumn.getArrayOfJsonArrays(String column) Get an array of value for the givencolumn.getArrayOfJsonObjects(String column) Get an array of value for the givencolumn.Object[]getArrayOfJsons(String column) Get an array of JSON elements for the givencolumn, the element might be#JSON_NULL nullor one of the following types: String Number JsonObject JsonArray BooleangetArrayOfLocalDates(String column) Get an array of value for the givencolumn.getArrayOfLocalDateTimes(String column) Get an array of value for the givencolumn.getArrayOfLocalTimes(String column) Get an array of value for the givencolumn.Long[]getArrayOfLongs(String column) Get an array ofLongvalue for the givencolumn.Numeric[]getArrayOfNumerics(String column) Get an array of value for the givencolumn.getArrayOfOffsetDateTimes(String column) Get an array of value for the givencolumn.getArrayOfOffsetTimes(String column) Get an array of value for the givencolumn.Short[]getArrayOfShorts(String column) Get an array ofShortvalue for the givencolumn.String[]getArrayOfStrings(String column) Get an array ofStringvalue for the givencolumn.Temporal[]getArrayOfTemporals(String column) Get an array of value for the givencolumn.UUID[]getArrayOfUUIDs(String column) Get an array of value for the givencolumn.getBigDecimal(String column) Get value for the givencolumn.getBoolean(String column) Get a boolean value for the givencolumn.Get a buffer value for the givencolumn.Get a byte value for the givencolumn.intgetColumnIndex(String column) Get a column position for the given @code column}.getColumnName(int pos) Get a column name atpos.Get a double value for the givencolumn.Get a float value for the givencolumn.getInteger(String column) Get an integer value for the givencolumn.Get a JSON element for the givencolumn, the element might be#JSON_NULL nullor one of the following types: String Number JsonObject JsonArray BooleangetJsonArray(String column) Get a value for the givencolumn.getJsonObject(String column) Get a value for the givencolumn.getLocalDate(String column) GetLocalDatevalue for the givencolumn.getLocalDateTime(String column) GetLocalDateTimevalue for the givencolumn.getLocalTime(String column) GetLocalTimevalue for the givencolumn.Get a long value for the givencolumn.getNumeric(String column) Get value for the givencolumn.getOffsetDateTime(String column) GetOffsetDateTimevalue for the givencolumn.getOffsetTime(String column) GetOffsetTimevalue for the givencolumn.Get a short value for the givencolumn.Get a string value for the givencolumn.getTemporal(String column) Get a temporal value for the givencolumn.GetUUIDvalue for the givencolumn.Get a value for the givencolumn.inthashCode()static RownewInstance(Row arg) voidrelease()Signal the row can be recycled, this is only effective when dealing with a row in a collector query and the row has already been processed and transformed.toJson()Return a JSON object representation of the row.toString()Methods inherited from class io.vertx.reactivex.sqlclient.Tuple
addArrayOfBigDecimal, addArrayOfBoolean, addArrayOfDouble, addArrayOfFloat, addArrayOfInteger, addArrayOfJsonArray, addArrayOfJsonObject, addArrayOfLocalDate, addArrayOfLocalDateTime, addArrayOfLocalTime, addArrayOfLong, addArrayOfOffsetDateTime, addArrayOfOffsetTime, addArrayOfShort, addArrayOfString, addArrayOfTemporal, addArrayOfUUID, addBigDecimal, addBoolean, addBuffer, addDouble, addFloat, addInteger, addJsonArray, addJsonObject, addLocalDate, addLocalDateTime, addLocalTime, addLong, addOffsetDateTime, addOffsetTime, addShort, addString, addTemporal, addUUID, addValue, clear, deepToString, from, from, get, getArrayOfBigDecimals, getArrayOfBooleans, getArrayOfBytes, getArrayOfDoubles, getArrayOfFloats, getArrayOfIntegers, getArrayOfJsonArrays, getArrayOfJsonObjects, getArrayOfJsons, getArrayOfLocalDates, getArrayOfLocalDateTimes, getArrayOfLocalTimes, getArrayOfLongs, getArrayOfNumerics, getArrayOfOffsetDateTimes, getArrayOfOffsetTimes, getArrayOfShorts, getArrayOfStrings, getArrayOfTemporals, getArrayOfUUIDs, getBigDecimal, getBoolean, getBuffer, getByte, getDouble, getFloat, getInteger, getJson, getJsonArray, getJsonObject, getLocalDate, getLocalDateTime, getLocalTime, getLong, getNumeric, getOffsetDateTime, getOffsetTime, getShort, getString, getTemporal, getUUID, getValue, newInstance, of, of, of, of, of, of, size, tuple, tuple, wrap, wrap
-
Field Details
-
__TYPE_ARG
-
JSON_NULL
The JSON null literal value.
It is used to distinguish a JSON null literal value from the Javanullvalue. This is only used when the database supports JSON types.
-
-
Constructor Details
-
Row
-
Row
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classTuple
-
getColumnName
Get a column name atpos.- Parameters:
pos- the column position- Returns:
- the column name or
null
-
getColumnIndex
Get a column position for the given @code column}.- Parameters:
column- the column name- Returns:
- the column name or
-1if not found
-
getValue
Get a value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getBoolean
Get a boolean value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getByte
Get a byte value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getShort
Get a short value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getInteger
Get an integer value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getLong
Get a long value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getFloat
Get a float value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getDouble
Get a double value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getString
Get a string value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getJson
Get a JSON element for the givencolumn, the element might be#JSON_NULL nullor one of the following types:- String
- Number
- JsonObject
- JsonArray
- Boolean
- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getJsonObject
Get a value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getJsonArray
Get a value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getBuffer
Get a buffer value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
get
LikeTuple.get(java.lang.Class<T>, int)but specifying thecolumninstead of the position.- Parameters:
type-column-- Returns:
-
toJson
Return a JSON object representation of the row.Column names are mapped to JSON keys.
The following rules are applied for the column values:
- number, boolean and string are preserved
- the
nullvalue is preserved - JSON elements are preserved
Bufferare converted to base64 encoded strings- array is mapped
JsonArray - otherwise the type converted to a string
- Returns:
- the json representation
-
release
public void release()Signal the row can be recycled, this is only effective when dealing with a row in a collector query and the row has already been processed and transformed. -
getNumeric
Get value for the givencolumn.- Parameters:
column- the column- Returns:
- the
columnvalue
-
getTemporal
Get a temporal value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getLocalDate
GetLocalDatevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getLocalTime
GetLocalTimevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getLocalDateTime
GetLocalDateTimevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getOffsetTime
GetOffsetTimevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getOffsetDateTime
GetOffsetDateTimevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getUUID
GetUUIDvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getBigDecimal
Get value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfBooleans
Get an array ofBooleanvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfBytes
Get an array ofBytevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfShorts
Get an array ofShortvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfIntegers
Get an array ofIntegervalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfLongs
Get an array ofLongvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfFloats
Get an array ofFloatvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfDoubles
Get an array ofDoublevalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfNumerics
Get an array of value for the givencolumn.- Parameters:
column- the column- Returns:
- the
columnvalue
-
getArrayOfStrings
Get an array ofStringvalue for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfJsonObjects
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfJsonArrays
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfTemporals
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfLocalDates
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfLocalTimes
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfLocalDateTimes
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfOffsetTimes
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfOffsetDateTimes
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfUUIDs
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfBigDecimals
Get an array of value for the givencolumn.- Parameters:
column- the column name- Returns:
- the
columnvalue
-
getArrayOfJsons
Get an array of JSON elements for the givencolumn, the element might be#JSON_NULL nullor one of the following types:- String
- Number
- JsonObject
- JsonArray
- Boolean
- Parameters:
column- the column name- Returns:
- the
columnvalue
-
newInstance
-