Package io.vertx.reactivex.sqlclient
Class RowSet<R>
- All Implemented Interfaces:
RxDelegate,Iterable<R>
The execution result of the row set of a query provided as
, commonly used as a RowSet|
.
Using a collector query might provide a different result.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescription -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()iterator()static <R> RowSet<R>newInstance(RowSet arg) static <R> RowSet<R>newInstance(RowSet arg, TypeArg<R> __typeArg_R) next()Return the next available result ornull, e.g for a simple query that executed multiple queries or for a batch result.stream()toString()value()Methods inherited from class io.vertx.reactivex.sqlclient.SqlResult
columnDescriptors, columnsNames, newInstance, newInstance, property, rowCount, rowDescriptor, sizeMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Iterable
forEach, spliterator
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
RowSet
-
RowSet
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classSqlResult<RowSet<R>>
-
value
-
iterator
-
next
Description copied from class:SqlResultReturn the next available result ornull, e.g for a simple query that executed multiple queries or for a batch result. -
stream
-
newInstance
-
newInstance
-