Package io.vertx.reactivex.sqlclient
Class Transaction
java.lang.Object
io.vertx.reactivex.sqlclient.Transaction
- All Implemented Interfaces:
RxDelegate
A transaction.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncommit()Commit the current transaction.Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.booleaninthashCode()static TransactionnewInstance(Transaction arg) rollback()Rollback the transaction and release the associated resources.io.reactivex.CompletablerxCommit()Commit the current transaction.io.reactivex.CompletableReturn the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.io.reactivex.CompletableRollback the transaction and release the associated resources.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
Transaction
-
Transaction
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
commit
Commit the current transaction.- Returns:
-
rxCommit
public io.reactivex.Completable rxCommit()Commit the current transaction.- Returns:
-
rollback
Rollback the transaction and release the associated resources.- Returns:
-
rxRollback
public io.reactivex.Completable rxRollback()Rollback the transaction and release the associated resources.- Returns:
-
completion
Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
rxCompletion
public io.reactivex.Completable rxCompletion()Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
newInstance
-