Class Tuple
- All Implemented Interfaces:
RxDelegate
- Direct Known Subclasses:
Row
CAUTION: indexes start at 0, not at 1.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddArrayOfBigDecimal(BigDecimal[] value) Add an array of value at the end of the tuple.addArrayOfBoolean(Boolean[] value) Add an array ofBooleanvalue at the end of the tuple.addArrayOfDouble(Double[] value) Add an array ofDoublevalue at the end of the tuple.addArrayOfFloat(Float[] value) Add an array ofFloatvalue at the end of the tuple.addArrayOfInteger(Integer[] value) Add an array ofIntegervalue at the end of the tuple.addArrayOfJsonArray(JsonArray[] value) Add an array of value at the end of the tuple.addArrayOfJsonObject(JsonObject[] value) Add an array of value at the end of the tuple.addArrayOfLocalDate(LocalDate[] value) Add an array of value at the end of the tuple.addArrayOfLocalDateTime(LocalDateTime[] value) Add an array of value at the end of the tuple.addArrayOfLocalTime(LocalTime[] value) Add an array of value at the end of the tuple.addArrayOfLong(Long[] value) Add an array ofLongvalue at the end of the tuple.addArrayOfOffsetDateTime(OffsetDateTime[] value) Add an array of value at the end of the tuple.addArrayOfOffsetTime(OffsetTime[] value) Add an array of value at the end of the tuple.addArrayOfShort(Short[] value) Add an array ofShortvalue at the end of the tuple.addArrayOfString(String[] value) Add an array ofStringvalue at the end of the tuple.addArrayOfTemporal(Temporal[] value) Add an array of value at the end of the tuple.addArrayOfUUID(UUID[] value) Add an array of value at the end of the tuple.addBigDecimal(BigDecimal value) Add a value at the end of the tuple.addBoolean(Boolean value) Add a boolean value at the end of the tuple.Add a buffer value at the end of the tuple.Add a double value at the end of the tuple.Add a float value at the end of the tuple.addInteger(Integer value) Add an integer value at the end of the tuple.addJsonArray(JsonArray value) Add a value at the end of the tuple.addJsonObject(JsonObject value) Add a value at the end of the tuple.addLocalDate(LocalDate value) Add aLocalDatevalue at the end of the tuple.addLocalDateTime(LocalDateTime value) Add aLocalDateTimevalue at the end of the tuple.addLocalTime(LocalTime value) Add aLocalTimevalue at the end of the tuple.Add a long value at the end of the tuple.addOffsetDateTime(OffsetDateTime value) Add aOffsetDateTimevalue at the end of the tuple.addOffsetTime(OffsetTime value) Add aOffsetTimevalue at the end of the tuple.Add a short value at the end of the tuple.Add a string value at the end of the tuple.addTemporal(Temporal value) Add aTemporalvalue at the end of the tuple.Add aUUIDvalue at the end of the tuple.Add an object value at the end of the tuple.voidclear()booleanstatic TupleWrap the providedarraywith a tuple.static <T> TupleWrap the providedlistwith a tuple.<T> TGet the the at the specifiedpositionand the specifiedtype.getArrayOfBigDecimals(int pos) Get an array of value atpos.Boolean[]getArrayOfBooleans(int pos) Get an array ofBooleanvalue atpos.Byte[]getArrayOfBytes(int pos) Get an array ofBytevalue atpos.Double[]getArrayOfDoubles(int pos) Get an array ofDoublevalue atpos.Float[]getArrayOfFloats(int pos) Get an array ofFloatvalue atpos.Integer[]getArrayOfIntegers(int pos) Get an array ofIntegervalue atpos.getArrayOfJsonArrays(int pos) Get an array of value atpos.getArrayOfJsonObjects(int pos) Get an array of value atpos.Object[]getArrayOfJsons(int pos) Get an array of JSON elements atpos, the element might be#JSON_NULL nullor one of the following types: String Number JsonObject JsonArray BooleangetArrayOfLocalDates(int pos) Get an array of value atpos.getArrayOfLocalDateTimes(int pos) Get an array of value atpos.getArrayOfLocalTimes(int pos) Get an array of value atpos.Long[]getArrayOfLongs(int pos) Get an array ofLongvalue atpos.Numeric[]getArrayOfNumerics(int pos) Get an array of value atpos.getArrayOfOffsetDateTimes(int pos) Get an array of value atpos.getArrayOfOffsetTimes(int pos) Get an array of value atpos.Short[]getArrayOfShorts(int pos) Get an array ofShortvalue atpos.String[]getArrayOfStrings(int pos) Get an array ofStringvalue atpos.Temporal[]getArrayOfTemporals(int pos) Get an array of value atpos.UUID[]getArrayOfUUIDs(int pos) Get an array of value atpos.getBigDecimal(int pos) Get value atpos.getBoolean(int pos) Get a boolean value atpos.getBuffer(int pos) Get a buffer value atpos.getByte(int pos) Get a byte value atpos.getDouble(int pos) Get a double value atpos.getFloat(int pos) Get a float value atpos.getInteger(int pos) Get an integer value atpos.getJson(int pos) Get a JSON element atpos, the element might be#JSON_NULL nullor one of the following types: String Number JsonObject JsonArray BooleangetJsonArray(int pos) Get a value atpos.getJsonObject(int pos) Get a value atpos.getLocalDate(int pos) GetLocalDatevalue atpos.getLocalDateTime(int pos) GetLocalDateTimevalue atpos.getLocalTime(int pos) GetLocalTimevalue atpos.getLong(int pos) Get a long value atpos.getNumeric(int pos) Get value atpos.getOffsetDateTime(int pos) GetOffsetDateTimevalue atpos.getOffsetTime(int pos) GetOffsetTimevalue atpos.getShort(int pos) Get a short value atpos.getString(int pos) Get a string value atpos.getTemporal(int pos) Get aTemporalvalue atpos.getUUID(int pos) GetUUIDvalue atpos.getValue(int pos) Get an object value atpos.inthashCode()static TuplenewInstance(Tuple arg) static TupleCreate a tuple of one element.static TupleCreate a tuple of two elements.static TupleCreate a tuple of three elements.static TupleCreate a tuple of four elements.static TupleCreate a tuple of five elements.static TupleCreate a tuple of six elements.intsize()toString()static Tupletuple()static TupleCreate a tuple with the providedelementslist.static TupleWrap the providedarraywith a tuple.static <T> TupleWrap the providedlistwith a tuple.
-
Field Details
-
__TYPE_ARG
-
JSON_NULL
The JSON null literal value.
It is used to distinguish a JSON null literal value from the Javanullvalue. This is only used when the database supports JSON types.
-
-
Constructor Details
-
Tuple
-
Tuple
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
tuple
- Returns:
- a new empty tuple
-
from
Wrap the providedlistwith a tuple.
The list is not copied and is used as store for tuple elements.- Parameters:
list-- Returns:
- the list wrapped as a tuple
-
wrap
Wrap the providedlistwith a tuple.
The list is not copied and is used as store for tuple elements.
Note: The list might be modified and users should usetuple()if the list is unmodifiable- Parameters:
list-- Returns:
- the list wrapped as a tuple
-
of
Create a tuple of one element.- Parameters:
elt1- the first value- Returns:
- the tuple
-
of
Create a tuple of two elements.- Parameters:
elt1- the first valueelt2- the second value- Returns:
- the tuple
-
of
Create a tuple of three elements.- Parameters:
elt1- the first valueelt2- the second valueelt3- the third value- Returns:
- the tuple
-
of
Create a tuple of four elements.- Parameters:
elt1- the first valueelt2- the second valueelt3- the third valueelt4- the fourth value- Returns:
- the tuple
-
of
Create a tuple of five elements.- Parameters:
elt1- the first valueelt2- the second valueelt3- the third valueelt4- the fourth valueelt5- the fifth value- Returns:
- the tuple
-
of
public static Tuple of(Object elt1, Object elt2, Object elt3, Object elt4, Object elt5, Object elt6) Create a tuple of six elements.- Parameters:
elt1- the first valueelt2- the second valuegelt3- the third valueelt4- the fourth valueelt5- the fifth valueelt6- the sixth value- Returns:
- the tuple
-
tuple
Create a tuple with the providedelementslist. Theelementslist is not modified.- Parameters:
elements- the list of elements- Returns:
- the tuple
-
getValue
Get an object value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getBoolean
Get a boolean value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getByte
Get a byte value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getShort
Get a short value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getInteger
Get an integer value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getLong
Get a long value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getFloat
Get a float value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getDouble
Get a double value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getString
Get a string value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getJsonObject
Get a value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getJsonArray
Get a value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getJson
Get a JSON element atpos, the element might be#JSON_NULL nullor one of the following types:- String
- Number
- JsonObject
- JsonArray
- Boolean
- Parameters:
pos- the position- Returns:
- the value
-
getBuffer
Get a buffer value atpos.- Parameters:
pos- the position- Returns:
- the value
-
addValue
Add an object value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addBoolean
Add a boolean value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addShort
Add a short value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addInteger
Add an integer value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addLong
Add a long value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addFloat
Add a float value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addDouble
Add a double value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addString
Add a string value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addJsonObject
Add a value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addJsonArray
Add a value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addBuffer
Add a buffer value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
get
Get the the at the specifiedpositionand the specifiedtype.The type can be one of the types returned by the row (e.g
String.class) or an array of the type (e.gString[].class)).- Parameters:
type- the expected value typeposition- the value position- Returns:
- the value if the value is found or null.
-
size
public int size()- Returns:
- the tuple size
-
clear
public void clear() -
deepToString
- Returns:
- A String containing the
Objectvalue of each element, separated by a comma (,) character
-
from
Wrap the providedarraywith a tuple.
The array is not copied and is used as store for tuple elements.- Parameters:
array-- Returns:
- the list wrapped as a tuple
-
wrap
Wrap the providedarraywith a tuple.
The array is not copied and is used as store for tuple elements.- Parameters:
array-- Returns:
- the list wrapped as a tuple
-
getNumeric
Get value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getTemporal
Get aTemporalvalue atpos.- Parameters:
pos- the position- Returns:
- the value
-
getLocalDate
- Parameters:
pos- the position- Returns:
- the value
-
getLocalTime
- Parameters:
pos- the position- Returns:
- the value
-
getLocalDateTime
GetLocalDateTimevalue atpos.- Parameters:
pos- the position- Returns:
- the value
-
getOffsetTime
GetOffsetTimevalue atpos.Target element instance of
OffsetDateTimewill be coerced toOffsetTime.- Parameters:
pos- the position- Returns:
- the value
-
getOffsetDateTime
GetOffsetDateTimevalue atpos.- Parameters:
pos- the position- Returns:
- the value
-
getUUID
GetUUIDvalue atpos.- Parameters:
pos- the position- Returns:
- the value
-
getBigDecimal
Get value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfBooleans
Get an array ofBooleanvalue atpos.Target element instance of
Object[]will be coerced toBoolean[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfBytes
Get an array ofBytevalue atpos.Target element instance of
Number[]orObject[]will be coerced toByte[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfShorts
Get an array ofShortvalue atpos.Target element instance of
Number[]orObject[]will be coerced toShort[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfIntegers
Get an array ofIntegervalue atpos.Target element instance of
Number[]orObject[]will be coerced toInteger[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfLongs
Get an array ofLongvalue atpos.Target element instance of
Number[]orObject[]will be coerced toLong[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfFloats
Get an array ofFloatvalue atpos.Target element instance of
Number[]orObject[]will be coerced toFloat[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfDoubles
Get an array ofDoublevalue atpos.Target element instance of
Number[]orObject[]will be coerced toDouble[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfNumerics
Get an array of value atpos.- Parameters:
pos- the column- Returns:
- the value
-
getArrayOfStrings
Get an array ofStringvalue atpos.Target element instance of
Object[]will be coerced toString[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfJsonObjects
Get an array of value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfJsonArrays
Get an array of value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfJsons
Get an array of JSON elements atpos, the element might be#JSON_NULL nullor one of the following types:- String
- Number
- JsonObject
- JsonArray
- Boolean
- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfTemporals
Get an array of value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfLocalDates
Get an array of value atpos.Target element instance of
LocalDateTime[]will be coerced toLocalDate[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfLocalTimes
Get an array of value atpos.Target element instance of
LocalDateTime[]will be coerced toLocalTime[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfLocalDateTimes
Get an array of value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfOffsetTimes
Get an array of value atpos.Target element instance of
OffsetDateTime[]will be coerced toOffsetTime[].- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfOffsetDateTimes
Get an array of value atpos.- Parameters:
pos- the position- Returns:
- the value
-
getArrayOfUUIDs
Get an array of value atpos.- Parameters:
pos- the column- Returns:
- the value
-
getArrayOfBigDecimals
Get an array of value atpos.- Parameters:
pos- the column- Returns:
- the value
-
addTemporal
Add aTemporalvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addLocalDate
Add aLocalDatevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addLocalTime
Add aLocalTimevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addLocalDateTime
Add aLocalDateTimevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addOffsetTime
Add aOffsetTimevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addOffsetDateTime
Add aOffsetDateTimevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addUUID
Add aUUIDvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addBigDecimal
Add a value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfBoolean
Add an array ofBooleanvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfShort
Add an array ofShortvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfInteger
Add an array ofIntegervalue at the end of the tuple.Target element instance of
Number[]will be coerced toInteger[].- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfLong
Add an array ofLongvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfFloat
Add an array ofFloatvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfDouble
Add an array ofDoublevalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfString
Add an array ofStringvalue at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfJsonObject
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfJsonArray
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfTemporal
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfLocalDate
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfLocalTime
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfLocalDateTime
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfOffsetTime
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfOffsetDateTime
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfUUID
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
addArrayOfBigDecimal
Add an array of value at the end of the tuple.- Parameters:
value- the value- Returns:
- a reference to this, so the API can be used fluently
-
newInstance
-